@@ -645,84 +645,6 @@ class BaseMatcher:
         node_path = self._build_node_path(start_idx, unique)
         return node_path, start_idx
 
-    def match_incremental(self, path, unique=True, tqdm=None, backtrace_len=None):
-        """Dynamic Programming based (HMM-like) map matcher, continue building lattice with the new path.
-
-        If the matcher fails to match the entire path, the last matched index is returned.
-        This index can be used to run the matcher again from that observation onwards.
-
-        :param path: list[Union[tuple[lat, lon], tuple[lat, lon, time]]
-        :param unique: Only retain unique nodes in the sequence (avoid repetitions)
-        :param tqdm: Use a tqdm progress reporter (default is None)
-        :param backtrace_len: Length of the computed path throught the lattice.
-          If None the path through the lattice will be the length of the last given path.
-          If -1, the full path is computed.
-        :return: Tuple of (List of state keys, index of last observation that was matched)
-        """
-        if __debug__:
-            logger.debug("Incrementally match path of length {}".format(len(path)))
-
-        # Initialisation
-        if self.path is None:
-            start_obs_idx = 1
-            self.path = path
-            nb_start_nodes = self._create_start_nodes()
-            if nb_start_nodes == 0:
-                return [], 0
-        else:
-            start_obs_idx = len(self.path)
-            for idx in range(len(self.path)):
-                self.lattice[start_obs_idx + idx] = LatticeColumn(start_obs_idx + idx)
-            self.path += path
-
-        # Start iterating over observations 1..end
-        t_start = time.time()
-        iterator = range(start_obs_idx, len(self.path))
-        if tqdm:
-            iterator = tqdm(iterator)
-        early_stop_idx = None
-        for obs_idx in iterator:
-            if __debug__:
-                logger.debug(f"--- obs {obs_idx} --- {self.path[obs_idx]} ---")
-            cnt_lat_size_not_zero = False
-            for m_tmp in self.lattice[obs_idx - 1].values(0):
-                if not m_tmp.stop:
-                    cnt_lat_size_not_zero = True
-                    break
-            # if len(self.lattice[obs_idx - 1]) == 0:
-            if not cnt_lat_size_not_zero:
-                if __debug__:
-                    logger.debug("No solutions found anymore")
-                early_stop_idx = obs_idx
-                logger.info(f'Stopped early at observation {early_stop_idx}')
-                break
-            self._match_states(obs_idx)
-            if self.non_emitting_states and not self._skip_ne_states(obs_idx):
-                # Fill in non-emitting states between previous and current observation
-                self._match_non_emitting_states(obs_idx - 1)
-            if __debug__:
-                if logger.isEnabledFor(logging.DEBUG):
-                    self.print_lattice(obs_idx=obs_idx, label_width=default_label_width, debug=True)
-
-        t_delta = time.time() - t_start
-        logger.info("Build lattice in {} seconds".format(t_delta))
-
-        # Backtrack to find best path
-        if early_stop_idx:
-            if early_stop_idx <= 1:
-                return [], 0
-            start_idx = early_stop_idx - 2
-        else:
-            start_idx = len(self.path) - 1
-        if backtrace_len is None:
-            max_depth = len(path)
-        elif backtrace_len == -1:
-            max_depth = None
-        else:
-            max_depth = backtrace_len
-        node_path = self._build_node_path(start_idx, unique, max_depth=max_depth)
-        return node_path, start_idx
-
     def _skip_ne_states(self, prev_m):
         # type: (BaseMatcher, BaseMatching) -> bool
         return False
@@ -1569,3 +1491,14 @@ class BaseMatcher:
             dist += self.map.distance(m_prev.edge_o.pi, m.edge_o.pi)
             m_prev = m
         return dist
+
+    def path_all_distances(self):
+        """Return a list of all distances between observed trace and map.
+
+        One entry for each point in the map and point in the trace that are mapped to each other.
+        In case non-emitting nodes are used, extra entries can be present where a point in the trace
+        or a point in the map is mapped to a segment.
+        """
+        path = self.lattice_best
+        dists = [m.dist_obs for m in path]
+        return dists
