@@ -191,8 +191,8 @@ def plot_map(map_con, path=None, nodes=None, counts=None, ax=None, use_osm=False
             path_startidx = 0
             path_slice = path
         px, py = zip(*[to_pixels(p[:2]) for p in path_slice])
-        ax.plot(px, py, 'o-', linewidth=linewidth, markersize=linewidth * 2, alpha=0.75,
-                linestyle="--", color=path_color)
+        ax.plot(px, py, linewidth=linewidth, markersize=linewidth * 2, alpha=0.75,
+                linestyle="--", marker='o', color=path_color)
         if show_labels:
             for li, (lx, ly) in enumerate(zip(px, py)):
                 # ax.text(lx, ly, f"O{li}", color=path_color)
